# ESA (C) 2000-2022
# 
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.

# XMMextractorpy.py

import os
from pysas.pyOAL import pyOAL
from pysas.logger import TaskLogger as TL
logger = TL('XMMextractorpy')
from .version import VERSION, SAS_RELEASE, SAS_AKA


__version__ = f'XMMextractorpy (XMMextractorpy-{VERSION}) [{SAS_RELEASE}-{SAS_AKA}]' 

def run(iparsdic):
    print(f'Executing {__file__} {iparsdic}')

    working_dir = iparsdic['workingDir']
    if working_dir == 'cwd':
        working_dir == os.getcwd()

    if os.path.isdir(working_dir):
        os.mkdir(working_dir)

    working_dir = os.path.abspath(working_dir)

    # Check type of parameter:
    runoption = iparsdic['runoption']
    if runoption.upper() == 'XML':
        param_file = iparsdic['paramfile']
        if os.path.isfile(param_file):
            obs = pyOAL.Observation(param_file)
        else:
            logger.log('error', 'Could not open {}.'.format(param_file))
            raise FileNotFoundError('Could not open {}.'.format(param_file))
    elif runoption.upper == 'OBSID':
        obsid = iparsdic['obsid']
        obsid_flag = pyOAL.check_if_valid_obsid(obsid)
        if obsid_flag:
            # Check for instruments
            epn = iparsdic['EPN']
            mos = iparsdic['MOS']
            rgs = iparsdic['RGS']
            om = iparsdic['OM']

            if 'Y' in epn.upper() or 'T' in epn.upper():
                epn = True
            else:
                epn = False
            if 'Y' in mos.upper() or 'T' in mos.upper():
                mos = True
            else:
                mos = False
            if 'Y' in rgs.upper() or 'T' in rgs.upper():
                rgs = True
            else:
                rgs = False
            if 'Y' in om.upper() or 'T' in om.upper():
                om = True
            else:
                om = False
 
            obs = pyOAL.Observation(obsid, working_dir, epn, mos, rgs, om)
        else:
            logger.log('error', 'Invalid OBSID.')
            raise TypeError('Invalid OBSID.')
    else:
        logger.log('error', 'runoption not available.')
        raise TypeError('runoption not available.')
        
        

